@@ -9,7 +9,7 @@
 package Dist::Zilla::Plugin::Git::GatherDir;
 # ABSTRACT: Gather all tracked files in a Git working directory
 
-our $VERSION = '2.043';
+our $VERSION = '2.046';
 
 use Moose;
 extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_match
@@ -31,7 +31,7 @@ extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_
 #pod This is a trivial variant of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
 #pod plugin.  It looks in the directory named in the L</root> attribute and adds all
 #pod the Git tracked files it finds there (as determined by C<git ls-files>).  If the
-#pod root begins with a tilde, the directory name is passed through C<glob()> first.
+#pod root begins with a tilde, the tilde portion is passed through C<glob()> first.
 #pod
 #pod Most users just need:
 #pod
@@ -53,7 +53,7 @@ extends 'Dist::Zilla::Plugin::GatherDir' => { -version => 4.200016 }; # exclude_
 #pod =cut
 
 use List::Util 1.45 qw(uniq);
-use MooseX::Types::Moose qw(Bool);
+use Types::Standard 'Bool';
 
 use namespace::autoclean;
 
@@ -153,14 +153,10 @@ override gather_files => sub {
 
   my $root = '' . $self->root;
 
-  # Convert ~ to home directory:
-  if ($root =~ /^~/) {
-    ($root) = glob($root);
-    warn 'old perl on Win32 detected: ~ in root not translated'
-      if $root =~ /^~/ and $^O eq 'Win32' && "$]" < '5.016';
-  }
+  # Convert ~ portion to real directory:
+  $root =~ s{^(~[^\\/]*)([\\/])}{$self->_homedir($1) . $2}e;
 
-  $root = Path::Tiny::path($root)->absolute($self->zilla->root->absolute);
+  $root = Path::Tiny::path($root)->absolute($self->zilla->root);
 
   # Prepare to gather files
   my $git = Git::Wrapper->new($root->stringify);
@@ -212,6 +208,19 @@ override gather_files => sub {
   return;
 };
 
+sub _homedir {
+  my ($self, $tilde_dir) = @_;
+
+  # other architectures have no issue with globbing any kind of ~user path
+  return (glob($tilde_dir))[0] if $^O ne 'Win32';
+
+  # on Win32, we can use the environment variable(s) for the current user
+  return "$]" < '5.016' ? $ENV{HOME} || $ENV{USERPROFILE} : (glob('~'))[0]
+    if $tilde_dir eq '~';
+
+  # but otherwise, we can't support this at all, on any version.
+  $self->log_fatal('expanding "' . $tilde_dir . '" on Win32 not supported');
+}
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
@@ -229,7 +238,7 @@ Dist::Zilla::Plugin::Git::GatherDir - Gather all tracked files in a Git working
 
 =head1 VERSION
 
-version 2.043
+version 2.046
 
 =head1 SYNOPSIS
 
@@ -248,7 +257,7 @@ In your F<dist.ini>:
 This is a trivial variant of the L<GatherDir|Dist::Zilla::Plugin::GatherDir>
 plugin.  It looks in the directory named in the L</root> attribute and adds all
 the Git tracked files it finds there (as determined by C<git ls-files>).  If the
-root begins with a tilde, the directory name is passed through C<glob()> first.
+root begins with a tilde, the tilde portion is passed through C<glob()> first.
 
 Most users just need:
 
@@ -348,8 +357,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
