@@ -13,7 +13,7 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Init;
 # ABSTRACT: Initialize git repository on dzil new
 
-our $VERSION = '2.043';
+our $VERSION = '2.046';
 
 our %transform = (
   lc => sub { lc shift },
@@ -31,7 +31,7 @@ use String::Formatter method_stringf => {
   },
 };
 
-use MooseX::Types::Moose qw(Str Bool ArrayRef);
+use Types::Standard qw(Str Bool ArrayRef);
 with 'Dist::Zilla::Role::AfterMint';
 use namespace::autoclean;
 
@@ -113,7 +113,7 @@ Dist::Zilla::Plugin::Git::Init - Initialize git repository on dzil new
 
 =head1 VERSION
 
-version 2.043
+version 2.046
 
 =head1 SYNOPSIS
 
@@ -188,8 +188,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
