@@ -13,11 +13,11 @@ use warnings;
 package Dist::Zilla::Plugin::Git::Push;
 # ABSTRACT: Push current branch
 
-our $VERSION = '2.043';
+our $VERSION = '2.046';
 
 use Moose;
 use MooseX::Has::Sugar;
-use MooseX::Types::Moose qw{ ArrayRef Str Bool };
+use Types::Standard qw{ ArrayRef Str Bool };
 
 use namespace::autoclean;
 
@@ -122,7 +122,7 @@ Dist::Zilla::Plugin::Git::Push - Push current branch
 
 =head1 VERSION
 
-version 2.043
+version 2.046
 
 =head1 SYNOPSIS
 
@@ -135,8 +135,8 @@ In your F<dist.ini>:
 
 =head1 DESCRIPTION
 
-Once the release is done, this plugin will push current git branch to
-remote end, with the associated tags.
+Once the release is done, this plugin will push the current git branch to
+the remote, with the associated tags.
 
 The plugin accepts the following options:
 
@@ -172,8 +172,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
