@@ -13,12 +13,12 @@ use warnings;
 package Dist::Zilla::Role::Git::DirtyFiles;
 # ABSTRACT: Provide the allow_dirty & changelog attributes
 
-our $VERSION = '2.043';
+our $VERSION = '2.046';
 
 use Moose::Role;
-use MooseX::Types::Moose qw{ Any ArrayRef Str RegexpRef };
-use MooseX::Types::Path::Tiny 0.010 qw{ Paths to_Paths };
-use Moose::Util::TypeConstraints;
+use Types::Standard qw{ Any ArrayRef Str RegexpRef };
+use Type::Utils qw(coerce from as via subtype);
+use Types::Path::Tiny 'Path';
 
 use namespace::autoclean;
 use Path::Tiny 0.048 qw(); # subsumes
@@ -55,11 +55,10 @@ requires qw(log_fatal repo_root zilla);
 {
   # We specifically allow the empty string to represent the empty list.
   # Otherwise, there'd be no way to specify an empty list in an INI file.
-  my $type = subtype as Paths;
-  coerce($type,
-    from ArrayRef, via { to_Paths( [ grep { length } @$_ ] ) },
-    from Any, via { length($_) ? to_Paths($_) : [] },
-  );
+  my $type = subtype as ArrayRef[Path];
+  coerce $type,
+    from ArrayRef, via { (ArrayRef[Path])->coerce( [ grep { length } @$_ ] ) },
+    from Any, via { length($_) ? (ArrayRef[Path])->coerce($_) : [] };
 
   has allow_dirty => (
     is => 'ro', lazy => 1,
@@ -129,26 +128,24 @@ sub list_dirty_files
   my $git_root  = $self->repo_root;
   my @filenames = @{ $self->allow_dirty };
 
-  if ($git_root ne '.') {
-    # Interpret allow_dirty relative to the dzil root
-    my $dzil_root = Path::Tiny::path($self->zilla->root)->absolute->realpath;
-    $git_root     = Path::Tiny::path($git_root)
-                      ->absolute($dzil_root)
-                      ->realpath;
+  # Interpret allow_dirty relative to the dzil root, not git root nor cwd
+  my $dzil_root = Path::Tiny::path($self->zilla->root)->absolute->realpath;
+  $git_root     = Path::Tiny::path($git_root)
+                    ->absolute($dzil_root)
+                    ->realpath;
 
-    $self->log_fatal("Dzil root $dzil_root is not inside Git root $git_root")
-        unless $git_root->subsumes($dzil_root);
+  $self->log_fatal("Dzil root $dzil_root is not inside Git root $git_root")
+      unless $git_root->subsumes($dzil_root);
 
-    for my $fn (@filenames) {
-      try {
-        $fn = Path::Tiny::path($fn)
-                ->absolute($dzil_root)
-                ->realpath            # process ..
-                ->relative($git_root)
-                ->stringify;
-      };
-    }
-  } # end if git root ne dzil root
+  for my $fn (@filenames) {
+    try {
+      $fn = Path::Tiny::path($fn)
+              ->absolute($dzil_root)
+              ->realpath            # process ..
+              ->relative($git_root)
+              ->stringify;
+    };
+  }
 
   my $allowed = join '|', @{ $self->allow_dirty_match }, map { qr{^\Q$_\E$} } @filenames;
 
@@ -173,7 +170,7 @@ Dist::Zilla::Role::Git::DirtyFiles - Provide the allow_dirty & changelog attribu
 
 =head1 VERSION
 
-version 2.043
+version 2.046
 
 =head1 DESCRIPTION
 
@@ -230,8 +227,6 @@ L<http://dzil.org/#mailing-list>.
 There is also an irc channel available for users of this distribution, at
 L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
-I am also usually active on irc, as 'ether' at C<irc.perl.org>.
-
 =head1 AUTHOR
 
 Jerome Quelin
